summaryrefslogtreecommitdiffstats
path: root/kspell2/client.h
diff options
context:
space:
mode:
Diffstat (limited to 'kspell2/client.h')
-rw-r--r--kspell2/client.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kspell2/client.h b/kspell2/client.h
index 203a9f0e3..86046e204 100644
--- a/kspell2/client.h
+++ b/kspell2/client.h
@@ -22,9 +22,9 @@
#ifndef KSPELL_CLIENT_H
#define KSPELL_CLIENT_H
-#include <qobject.h>
-#include <qstringlist.h>
-#include <qstring.h>
+#include <tqobject.h>
+#include <tqstringlist.h>
+#include <tqstring.h>
#include <kdelibs_export.h>
@@ -33,24 +33,24 @@ namespace KSpell2
class Dictionary;
/**
* The fact that this class inherits from QObject makes me
* hugely unhappy. The reason for as of writting is that
* I don't really feel like writting my own KLibFactory
* that would load anything else then QObject derivatives.
*/
class KDE_EXPORT Client : public QObject
{
Q_OBJECT
public:
- Client( QObject *parent = 0, const char *name=0 );
+ Client( TQObject *parent = 0, const char *name=0 );
virtual int reliability() const = 0;
- virtual Dictionary* dictionary( const QString& language ) =0;
+ virtual Dictionary* dictionary( const TQString& language ) =0;
- virtual QStringList languages() const =0;
+ virtual TQStringList languages() const =0;
- virtual QString name() const =0;
+ virtual TQString name() const =0;
};
}
@@ -33,24 +33,24 @@ namespace KSpell2
class Dictionary;
/**
- * The fact that this class inherits from QObject makes me
+ * The fact that this class inherits from TQObject makes me
* hugely unhappy. The reason for as of writting is that
* I don't really feel like writting my own KLibFactory
@@ -33,24 +33,24 @@ namespace KSpell2
* hugely unhappy. The reason for as of writting is that
* I don't really feel like writting my own KLibFactory
- * that would load anything else then QObject derivatives.
+ * that would load anything else then TQObject derivatives.
*/
class KDE_EXPORT Client : public QObject